==> buzztard_0.5.0.orig.tar.gz: buzztard-0.5.0/src/lib/core/marshal.h <==

#ifndef __bt_marshal_MARSHAL_H__
#define __bt_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:ULONG,ULONG (./marshal.list:4) */
extern void bt_marshal_VOID__ULONG_ULONG (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:ULONG,ULONG,ULONG (./marshal.list:5) */
extern void bt_marshal_VOID__ULONG_ULONG_ULONG (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:ULONG,OBJECT,ULONG (./marshal.list:6) */
extern void bt_marshal_VOID__ULONG_OBJECT_ULONG (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

G_END_DECLS

#endif /* __bt_marshal_MARSHAL_H__ */

==> buzztard_0.6.0.orig.tar.gz: buzztard-0.6.0/src/lib/core/marshal.h <==

#ifndef __bt_marshal_MARSHAL_H__
#define __bt_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:OBJECT,ULONG (./marshal.list:4) */
extern void bt_marshal_VOID__OBJECT_ULONG (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:ULONG,OBJECT,ULONG (./marshal.list:5) */
extern void bt_marshal_VOID__ULONG_OBJECT_ULONG (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:ULONG,ULONG (./marshal.list:6) */
extern void bt_marshal_VOID__ULONG_ULONG (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:ULONG,ULONG,ULONG (./marshal.list:7) */
extern void bt_marshal_VOID__ULONG_ULONG_ULONG (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

G_END_DECLS

#endif /* __bt_marshal_MARSHAL_H__ */
